# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from sigma import Petstore, AsyncPetstore
from sigma.types import Order, TradingListResponse
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestTrading:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_list(self, client: Petstore) -> None:
        trading = client.trading.list()
        assert_matches_type(TradingListResponse, trading, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Petstore) -> None:
        response = client.trading.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        trading = response.parse()
        assert_matches_type(TradingListResponse, trading, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Petstore) -> None:
        with client.trading.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            trading = response.parse()
            assert_matches_type(TradingListResponse, trading, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_submit(self, client: Petstore) -> None:
        trading = client.trading.submit()
        assert_matches_type(Order, trading, path=["response"])

    @parametrize
    def test_method_submit_with_all_params(self, client: Petstore) -> None:
        trading = client.trading.submit(
            order_id="orderId",
            price="price",
            quantity="quantity",
            side="buy",
            symbol="symbol",
            type="market",
        )
        assert_matches_type(Order, trading, path=["response"])

    @parametrize
    def test_raw_response_submit(self, client: Petstore) -> None:
        response = client.trading.with_raw_response.submit()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        trading = response.parse()
        assert_matches_type(Order, trading, path=["response"])

    @parametrize
    def test_streaming_response_submit(self, client: Petstore) -> None:
        with client.trading.with_streaming_response.submit() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            trading = response.parse()
            assert_matches_type(Order, trading, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncTrading:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_list(self, async_client: AsyncPetstore) -> None:
        trading = await async_client.trading.list()
        assert_matches_type(TradingListResponse, trading, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncPetstore) -> None:
        response = await async_client.trading.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        trading = await response.parse()
        assert_matches_type(TradingListResponse, trading, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncPetstore) -> None:
        async with async_client.trading.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            trading = await response.parse()
            assert_matches_type(TradingListResponse, trading, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_submit(self, async_client: AsyncPetstore) -> None:
        trading = await async_client.trading.submit()
        assert_matches_type(Order, trading, path=["response"])

    @parametrize
    async def test_method_submit_with_all_params(self, async_client: AsyncPetstore) -> None:
        trading = await async_client.trading.submit(
            order_id="orderId",
            price="price",
            quantity="quantity",
            side="buy",
            symbol="symbol",
            type="market",
        )
        assert_matches_type(Order, trading, path=["response"])

    @parametrize
    async def test_raw_response_submit(self, async_client: AsyncPetstore) -> None:
        response = await async_client.trading.with_raw_response.submit()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        trading = await response.parse()
        assert_matches_type(Order, trading, path=["response"])

    @parametrize
    async def test_streaming_response_submit(self, async_client: AsyncPetstore) -> None:
        async with async_client.trading.with_streaming_response.submit() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            trading = await response.parse()
            assert_matches_type(Order, trading, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.market.ticker import Ticker

__all__ = ["TickerResource", "AsyncTickerResource"]


class TickerResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TickerResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return TickerResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TickerResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return TickerResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Ticker:
        """Get real-time ticker"""
        return self._get(
            "/market/ticker",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Ticker,
        )

    def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Ticker:
        """Get real-time ticker"""
        return self._get(
            "/market/ticker",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Ticker,
        )


class AsyncTickerResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTickerResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTickerResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTickerResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return AsyncTickerResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Ticker:
        """Get real-time ticker"""
        return await self._get(
            "/market/ticker",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Ticker,
        )

    async def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Ticker:
        """Get real-time ticker"""
        return await self._get(
            "/market/ticker",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Ticker,
        )


class TickerResourceWithRawResponse:
    def __init__(self, ticker: TickerResource) -> None:
        self._ticker = ticker

        self.retrieve = to_raw_response_wrapper(
            ticker.retrieve,
        )
        self.get = to_raw_response_wrapper(
            ticker.get,
        )


class AsyncTickerResourceWithRawResponse:
    def __init__(self, ticker: AsyncTickerResource) -> None:
        self._ticker = ticker

        self.retrieve = async_to_raw_response_wrapper(
            ticker.retrieve,
        )
        self.get = async_to_raw_response_wrapper(
            ticker.get,
        )


class TickerResourceWithStreamingResponse:
    def __init__(self, ticker: TickerResource) -> None:
        self._ticker = ticker

        self.retrieve = to_streamed_response_wrapper(
            ticker.retrieve,
        )
        self.get = to_streamed_response_wrapper(
            ticker.get,
        )


class AsyncTickerResourceWithStreamingResponse:
    def __init__(self, ticker: AsyncTickerResource) -> None:
        self._ticker = ticker

        self.retrieve = async_to_streamed_response_wrapper(
            ticker.retrieve,
        )
        self.get = async_to_streamed_response_wrapper(
            ticker.get,
        )
